==> fitment-service-1.0.2-20190222.083908-2-sources.jar: com/bizvane/fitmentservice/models/bo/AppletBrandFunctionBo.java <==
package com.bizvane.fitmentservice.models.bo;

import com.bizvane.fitmentservice.models.po.AppletFunctionPO;

/**
 * @author liufq
 */
public class AppletBrandFunctionBo extends AppletFunctionPO{
    private String functionName;
    private String functionUrl;
    private String functionLogo;
    private Integer sort;
    private Long appletFunctionId;
    private int choice;
    private Long brandId;
    private String functionLogoOne;
    private AppletFunctionPO appletFunctionPO;

    private Boolean customerText;

    public Boolean getCustomerText() {
        return customerText;
    }

    public void setCustomerText(Boolean customerText) {
        this.customerText = customerText;
    }

    public String getFunctionLogoOne() {
        return functionLogoOne;
    }

    public void setFunctionLogoOne(String functionLogoOne) {
        this.functionLogoOne = functionLogoOne;
    }

    public String getFunctionName() {
        return functionName;
    }

    public void setFunctionName(String functionName) {
        this.functionName = functionName;
    }

    public String getFunctionUrl() {
        return functionUrl;
    }

    public void setFunctionUrl(String functionUrl) {
        this.functionUrl = functionUrl;
    }

    public String getFunctionLogo() {
        return functionLogo;
    }

    public void setFunctionLogo(String functionLogo) {
        this.functionLogo = functionLogo;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getAppletFunctionId() {
        return appletFunctionId;
    }

    public void setAppletFunctionId(Long appletFunctionId) {
        this.appletFunctionId = appletFunctionId;
    }

    public int getChoice() {
        return choice;
    }

    public void setChoice(int choice) {
        this.choice = choice;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public AppletFunctionPO getAppletFunctionPO() {
        return appletFunctionPO;
    }

    public void setAppletFunctionPO(AppletFunctionPO appletFunctionPO) {
        this.appletFunctionPO = appletFunctionPO;
    }
}

==> fitment-service-1.0.2-20190425.051956-8-sources.jar: com/bizvane/fitmentservice/models/bo/AppletBrandFunctionBo.java <==
package com.bizvane.fitmentservice.models.bo;

import com.bizvane.fitmentservice.models.po.AppletFunctionPO;

/**
 * @author liufq
 */
public class AppletBrandFunctionBo extends AppletFunctionPO{
    private String functionName;
    private String functionUrl;
    private String functionLogo;
    private Integer sort;
    private Long appletFunctionId;
    private int choice;
    private Long brandId;
    private String functionLogoOne;
    private AppletFunctionPO appletFunctionPO;

    private String customFunctionName;
    private Boolean customerName;


    private Boolean customerText;

    public Boolean getCustomerName() {
        return customerName;
    }

    public void setCustomerName(Boolean customerName) {
        this.customerName = customerName;
    }

    public String getCustomFunctionName() {
        return customFunctionName;
    }

    public void setCustomFunctionName(String customFunctionName) {
        this.customFunctionName = customFunctionName;
    }

    public Boolean getCustomerText() {
        return customerText;
    }

    public void setCustomerText(Boolean customerText) {
        this.customerText = customerText;
    }

    public String getFunctionLogoOne() {
        return functionLogoOne;
    }

    public void setFunctionLogoOne(String functionLogoOne) {
        this.functionLogoOne = functionLogoOne;
    }

    public String getFunctionName() {
        return functionName;
    }

    public void setFunctionName(String functionName) {
        this.functionName = functionName;
    }

    public String getFunctionUrl() {
        return functionUrl;
    }

    public void setFunctionUrl(String functionUrl) {
        this.functionUrl = functionUrl;
    }

    public String getFunctionLogo() {
        return functionLogo;
    }

    public void setFunctionLogo(String functionLogo) {
        this.functionLogo = functionLogo;
    }

    public Integer getSort() {
        return sort;
    }

    public void setSort(Integer sort) {
        this.sort = sort;
    }

    public Long getAppletFunctionId() {
        return appletFunctionId;
    }

    public void setAppletFunctionId(Long appletFunctionId) {
        this.appletFunctionId = appletFunctionId;
    }

    public int getChoice() {
        return choice;
    }

    public void setChoice(int choice) {
        this.choice = choice;
    }

    public Long getBrandId() {
        return brandId;
    }

    public void setBrandId(Long brandId) {
        this.brandId = brandId;
    }

    public AppletFunctionPO getAppletFunctionPO() {
        return appletFunctionPO;
    }

    public void setAppletFunctionPO(AppletFunctionPO appletFunctionPO) {
        this.appletFunctionPO = appletFunctionPO;
    }
}
